@@ -11,8 +11,8 @@
 
 G_BEGIN_DECLS
 
-/* Please keep this enum in sync with #keys, and the section gtkdoc,
- * in debug.c */
+/* Please keep this enum in sync with #keys, the section gtkdoc,
+ * and #key_to_domain, in debug.c */
 typedef enum
 {
   TP_DEBUG_GROUPS        = 1 << 1,
@@ -25,7 +25,9 @@ typedef enum
   TP_DEBUG_CHANNEL       = 1 << 8,
   TP_DEBUG_PROXY         = 1 << 9,
   TP_DEBUG_HANDLES       = 1 << 10,
-  TP_DEBUG_CONTACTS      = 1 << 11
+  TP_DEBUG_CONTACTS      = 1 << 11,
+  TP_DEBUG_ACCOUNTS      = 1 << 12,
+  TP_DEBUG_DISPATCHER    = 1 << 13
 } TpDebugFlags;
 
 gboolean _tp_debug_flag_is_set (TpDebugFlags flag);
