@@ -21,11 +21,33 @@ test_strv_contains (void)
   g_assert (!tp_strv_contains (strv, "Snakes!"));
 }
 
+static void
+test_value_array_build (void)
+{
+  GValueArray *arr;
+  const gchar *host = "badger.snakes";
+  guint port = 128;
+
+  arr = tp_value_array_build (2,
+    G_TYPE_STRING, host,
+    G_TYPE_UINT, port,
+    G_TYPE_INVALID);
+
+  g_assert (!tp_strdiff (g_value_get_string (g_value_array_get_nth (arr, 0)),
+    host));
+
+  g_assert (g_value_get_uint (g_value_array_get_nth (arr, 1)) == port);
+
+  g_value_array_free (arr);
+}
+
 int main (int argc, char **argv)
 {
   GPtrArray *ptrarray;
   gchar *string;
 
+  g_type_init ();
+
   g_assert (!tp_strdiff (NULL, NULL));
   g_assert (tp_strdiff ("badger", NULL));
   g_assert (tp_strdiff (NULL, "badger"));
@@ -54,5 +76,7 @@ int main (int argc, char **argv)
 
   test_strv_contains ();
 
+  test_value_array_build ();
+
   return 0;
 }
