@@ -28,7 +28,7 @@ import xml.dom.minidom
 from getopt import gnu_getopt
 
 from libglibcodegen import Signature, type_to_gtype, cmp_by_name, \
-        camelcase_to_lower, get_docstring, xml_escape
+        get_docstring, xml_escape, get_deprecated
 
 
 NS_TP = "http://telepathy.freedesktop.org/wiki/DbusSpec#extensions-v0"
@@ -55,6 +55,9 @@ class Generator(object):
             % opts.get('--subclass', 'TpProxy'))
         if self.proxy_arg == 'void *':
             self.proxy_arg = 'gpointer '
+        self.generate_reentrant = ('--generate-reentrant' in opts or
+                '--deprecate-reentrant' in opts)
+        self.deprecate_reentrant = opts.get('--deprecate-reentrant', None)
 
     def h(self, s):
         if isinstance(s, unicode):
@@ -78,7 +81,11 @@ class Generator(object):
         iface_lc = iface.lower()
 
         member = signal.getAttribute('name')
-        member_lc = camelcase_to_lower(member)
+        member_lc = signal.getAttribute('tp:name-for-bindings')
+        if member != member_lc.replace('_', ''):
+            raise AssertionError('Signal %s tp:name-for-bindings (%s) does '
+                    'not match' % (member, member_lc))
+        member_lc = member_lc.lower()
         member_uc = member_lc.upper()
 
         arg_count = 0
@@ -358,7 +365,11 @@ class Generator(object):
         iface_lc = iface.lower()
 
         member = method.getAttribute('name')
-        member_lc = camelcase_to_lower(member)
+        member_lc = method.getAttribute('tp:name-for-bindings')
+        if member != member_lc.replace('_', ''):
+            raise AssertionError('Method %s tp:name-for-bindings (%s) does '
+                    'not match' % (member, member_lc))
+        member_lc = member_lc.lower()
         member_uc = member_lc.upper()
 
         in_count = 0
@@ -421,6 +432,13 @@ class Generator(object):
         self.b(' * Signature of the callback called when a %s method call'
                % member)
         self.b(' * succeeds or fails.')
+
+        deprecated = method.getElementsByTagName('tp:deprecated')
+        if deprecated:
+            d = deprecated[0]
+            self.b(' *')
+            self.b(' * Deprecated: %s' % xml_escape(get_deprecated(d)))
+
         self.b(' */')
 
         callback_name = '%s_%s_callback_for_%s' % (self.prefix_lc, iface_lc,
@@ -681,6 +699,13 @@ class Generator(object):
         self.b(' *  progress. It is borrowed from the object, and will become')
         self.b(' *  invalid when the callback is called, the call is')
         self.b(' *  cancelled or the #TpProxy becomes invalid.')
+
+        deprecated = method.getElementsByTagName('tp:deprecated')
+        if deprecated:
+            d = deprecated[0]
+            self.b(' *')
+            self.b(' * Deprecated: %s' % xml_escape(get_deprecated(d)))
+
         self.b(' */')
         self.b('TpProxyPendingCall *\n%s_%s_call_%s (%sproxy,'
                % (self.prefix_lc, iface_lc, member_lc, self.proxy_arg))
@@ -793,6 +818,16 @@ class Generator(object):
         self.b('}')
         self.b('')
 
+        if self.generate_reentrant:
+            self.do_method_reentrant(method, iface_lc, member, member_lc,
+                                     in_args, out_args, collect_callback)
+
+        # leave a gap for the end of the method
+        self.b('')
+        self.h('')
+
+    def do_method_reentrant(self, method, iface_lc, member, member_lc, in_args,
+            out_args, collect_callback):
         # Reentrant blocking calls
         # Example:
         # gboolean tp_cli_properties_interface_run_get_properties
@@ -813,8 +848,8 @@ class Generator(object):
 
             self.b('    %s*%s;' % (ctype, name))
 
-        self.b('    gboolean success:1;')
-        self.b('    gboolean completed:1;')
+        self.b('    unsigned success:1;')
+        self.b('    unsigned completed:1;')
         self.b('} _%s_%s_run_state_%s;'
                % (self.prefix_lc, iface_lc, member_lc))
 
@@ -877,6 +912,9 @@ class Generator(object):
         self.b('}')
         self.b('')
 
+        if self.deprecate_reentrant:
+            self.h('#ifndef %s' % self.deprecate_reentrant)
+
         self.h('gboolean %s_%s_run_%s (%sproxy,'
                % (self.prefix_lc, iface_lc, member_lc, self.proxy_arg))
         self.h('    gint timeout_ms,')
@@ -918,6 +956,13 @@ class Generator(object):
         self.b(' * %s' % xml_escape(get_docstring(method) or '(Undocumented)'))
         self.b(' *')
         self.b(' * Returns: TRUE on success, FALSE and sets @error on error')
+
+        deprecated = method.getElementsByTagName('tp:deprecated')
+        if deprecated:
+            d = deprecated[0]
+            self.b(' *')
+            self.b(' * Deprecated: %s' % xml_escape(get_deprecated(d)))
+
         self.b(' */')
         self.b('gboolean\n%s_%s_run_%s (%sproxy,'
                % (self.prefix_lc, iface_lc, member_lc, self.proxy_arg))
@@ -940,7 +985,13 @@ class Generator(object):
             self.b('    %s*%s,' % (ctype, name))
 
         self.h('    GError **error,')
-        self.h('    GMainLoop **loop);')
+
+        if self.deprecate_reentrant:
+            self.h('    GMainLoop **loop) G_GNUC_DEPRECATED;')
+            self.h('#endif /* not %s */' % self.deprecate_reentrant)
+        else:
+            self.h('    GMainLoop **loop);')
+
         self.h('')
 
         self.b('    GError **error,')
@@ -1012,10 +1063,6 @@ class Generator(object):
         self.b('}')
         self.b('')
 
-        # leave a gap for the end of the method
-        self.b('')
-        self.h('')
-
     def do_signal_add(self, signal):
         marshaller_items = []
         gtypes = []
@@ -1145,7 +1192,8 @@ def types_to_gtypes(types):
 if __name__ == '__main__':
     options, argv = gnu_getopt(sys.argv[1:], '',
                                ['group=', 'subclass=', 'subclass-assert=',
-                                'iface-quark-prefix=', 'tp-proxy-api='])
+                                'iface-quark-prefix=', 'tp-proxy-api=',
+                                'generate-reentrant', 'deprecate-reentrant='])
 
     opts = {}
 
